@@ -4,7 +4,7 @@ from typing import Any, Callable, List, Optional, Dict, Union, Type
 import numpy as np
 import numpy.typing as npt
 
-from code_loader.contract.enums import DataStateType, DataStateEnum, LeapDataType, ConfusionMatrixValue
+from code_loader.contract.enums import DataStateType, DataStateEnum, LeapDataType, ConfusionMatrixValue, MetricDirection
 from code_loader.contract.visualizer_classes import LeapImage, LeapText, LeapGraph, LeapHorizontalBar, \
     LeapTextMask, LeapImageMask, LeapImageWithBBox
 
@@ -87,6 +87,11 @@ class MetricHandler:
     name: str
     function: Union[CustomCallableInterfaceMultiArgs, ConfusionMatrixCallableInterfaceMultiArgs]
     arg_names: List[str]
+    direction: Optional[MetricDirection] = MetricDirection.Downward
+
+@dataclass
+class RawInputsForHeatmap:
+    raw_input_by_vizualizer_arg_name: Dict[str, np.array]
 
 
 @dataclass
@@ -124,7 +129,7 @@ class MetadataHandler:
 class PredictionTypeHandler:
     name: str
     labels: List[str]
-    channel_dim: Optional[int] = -1
+    channel_dim: int
 
 
 @dataclass
